# ---------- Global variables ----------
# Set encoding of files and set locale
options(encoding="UTF-8")
Sys.setlocale(category="LC_ALL", locale="C")

# Working directory
setwd("~/Desktop/Projekte/Habilitation/Eco-Metabolomics/outreach/2018-02-29 Current Challenges Eco-Metabolomics Review")

# Preparations for plotting
par(mfrow=c(1,1), mar=c(4,4,4,1), oma=c(0,0,0,0), cex.axis=0.9, cex=0.8)



# ---------- Barplot search hits overview ----------
# Import from csv
search_hits <- read.csv("ecometabolomics_search_overview.csv", header=TRUE, sep=";", quote="\"", fill=FALSE, dec=",", stringsAsFactors=FALSE)
search_terms <- gsub(" \\+ "," \\+\n",search_hits$search.terms)

# Plot
pdf("ecometabolomics_search_overview.pdf", encoding="ISOLatin1", pointsize=12, width=5, height=5, family="Helvetica")
par(mfrow=c(1,1), mar=c(9,4,2,1), oma=c(0,0,0,0), cex.axis=0.9, cex.lab=1.1, cex=1.1)
barplot(height=search_hits$search.hits, ylab="number of papers", ylim=c(0,4000), names.arg=NULL, las=2)
text(x=seq(0.5,nrow(search_hits)+0.5,by=1.25), y=par("usr")[3]-par("usr")[4]/25, srt=75, adj=1, xpd=TRUE, labels=search_terms)
text(x=seq(0.7,nrow(search_hits)+0.5,by=1.2), y=search_hits$search.hits, xpd=TRUE, adj=0.5, pos=3, labels=search_hits$search.hits)
mtext(text="search terms", adj=0.5, line=7.5, side=1, font=1, cex=1.1)
mtext(text="(a)", adj=-0.15, line=0.5, font=2, cex=1.4)
dev.off()



# ---------- Barplot search hits development ----------
# Import from csv
search_dev <- read.csv("ecometabolomics_search_development.csv", header=TRUE, sep=";", quote="\"", fill=FALSE, dec=",", stringsAsFactors=FALSE)

# Plot
pdf("ecometabolomics_search_development.pdf", encoding="ISOLatin1", pointsize=12, width=5, height=5, family="Helvetica")
par(mfrow=c(1,1), mar=c(3,4,1,1), oma=c(0,0,0,0), cex.axis=0.9, cex.lab=1.1, cex=1.1)
barplot(height=as.matrix(t(search_dev[,3:4])), beside=TRUE, names.arg=NULL, legend.text=c("P+M+E","P+M+D"), args.legend=list(x="topleft",bty="n"))
text(seq(par("usr")[2]/7/2,par("usr")[2],by=par("usr")[2]/7), par("usr")[3]-par("usr")[4]/50, srt=75, adj=1, xpd=TRUE, labels=search_dev$year)
dev.off()



# ---------- Barplot interaction levels ----------
# Import from csv
int_lev <- read.csv("ecometabolomics_interactions.csv", header=TRUE, sep=";", quote="\"", fill=FALSE, dec=",", stringsAsFactors=FALSE)

# Plot
pdf("ecometabolomics_interactions.pdf", encoding="ISOLatin1", pointsize=12, width=5, height=5, family="Helvetica")
par(mfrow=c(1,1), mar=c(9,4,2,1), oma=c(0,0,0,0), cex.axis=0.9, cex.lab=1.1, cex=1.1)
barplot(height=int_lev$number.of.studies, ylab="number of studies", names.arg=NULL, las=2)
text(x=seq(par("usr")[2]/5/2,par("usr")[2],by=par("usr")[2]/5), y=par("usr")[3]-par("usr")[4]/50, srt=75, adj=1, xpd=TRUE, labels=int_lev$interaction.level)
text(x=seq(0.7,nrow(int_lev)+0.5,by=1.2), y=int_lev$number.of.studies, xpd=TRUE, adj=0.5, pos=3, labels=int_lev$number.of.studies)
mtext(text="interactions", adj=0.5, line=7.5, side=1, font=1, cex=1.1)
mtext(text="(b)", adj=-0.15, line=0.5, font=2, cex=1.4)
dev.off()



# ---------- Barplot acquisition methods ----------
# Import from csv
ac_met <- read.csv("ecometabolomics_acquisitions.csv", header=TRUE, sep=";", quote="\"", fill=FALSE, dec=",", stringsAsFactors=FALSE)

# Plot
pdf("ecometabolomics_acquisitions.pdf", encoding="ISOLatin1", pointsize=12, width=5, height=5, family="Helvetica")
par(mfrow=c(1,1), mar=c(9,4,2,1), oma=c(0,0,0,0), cex.axis=0.9, cex.lab=1.1, cex=1.1)
barplot(height=ac_met$number.of.studies, ylab="number of studies", names.arg=NULL, las=2)
text(x=seq(par("usr")[2]/5/2,par("usr")[2],by=par("usr")[2]/5), y=par("usr")[3]-par("usr")[4]/50, srt=75, adj=1, cex=0.9, xpd=TRUE, labels=ac_met$acquisition.method)
text(x=seq(0.7,nrow(ac_met)+0.5,by=1.2), y=ac_met$number.of.studies, xpd=TRUE, adj=0.5, pos=3, labels=ac_met$number.of.studies)
mtext(text="acquisition methods", adj=0.5, line=7.5, side=1, font=1, cex=1.1)
mtext(text="(c)", adj=-0.15, line=0.5, font=2, cex=1.4)
dev.off()


